@@ -31,5 +31,5 @@ else
 fi
 ( cd usr/bin ; rm -rf slogin )
 ( cd usr/bin ; ln -sf ./ssh slogin )
-( cd usr/man/man1 ; rm -rf slogin.1 )
-( cd usr/man/man1 ; ln -sf ./ssh.1 slogin.1 )
+( cd usr/man/man1 ; rm -rf slogin.1.gz )
+( cd usr/man/man1 ; ln -sf ssh.1.gz slogin.1.gz )
